@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
 """Webscraper for WaybackMachine.
- 
+
 Archive URL: https://archive.org/web/
 Todo:
     * caching
 """
 
 import pkg_resources
-from .fetch import *
+from .fetch import browse, WaybackMachineRecord, WaybackMachineError
 
 try:
     __version__ = pkg_resources.get_distribution("waybackmachine").version
